# -*- coding: utf-8 -*-
# -*- mode: python -*-
"""
An "abstract base" for classes that do pairwise comparisons.

Copyright (C) 2011 Daniel Meliza <dan // meliza.org>
Created 2011-08-30
"""


class base_comparison():
    """
    An abstract class with the methods required for a comparison
    operation. A comparison method consists of the following
    operations:

    1. Loading data from files. Some preprocessing may be necessary
    (e.g. computing spectrograms, denoising).

    2. Making pairwise comparisons and outputting statistics of the
    comparison.

    The symmetric property should be True if d(A,B)==d(B,A)
    """

    symmetric = True
    file_extension = None

    def load_signal(self, locator):
        """
        The signal stored under <locator> is loaded from disk,
        preprocessed, and returned in a form ready for pairwise
        comparison.  IMPORTANT: the data are stored in shared memory
        """
        pass

    def compare(self, ref, tgt):
        """
        Compare ref to tgt and return statistics of comparisons. <ref>
        and <tgt> arguments are the data structures generated by load_signal.
        """
        pass

    @property
    def compare_stat_fields(self):
        """ Return a tuple of the names for the statistics returned by compare() """
        pass

# Variables:
# End:
